==> scaleway_qaas_client-0.1.0.tar.gz: scaleway_qaas_client-0.1.0/scaleway_qaas_client/__init__.py <==
# Copyright 2025 Scaleway
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
from quantum_as_a_service_api_client.models import (
    ScalewayQaasV1Alpha1Platform as QaaSPlatform,
)
from quantum_as_a_service_api_client.models import (
    ScalewayQaasV1Alpha1PlatformAvailability as QaaSPlatformAvailability,
)
from quantum_as_a_service_api_client.models import (
    ScalewayQaasV1Alpha1PlatformTechnology as QaaSPlatformTechnology,
)
from quantum_as_a_service_api_client.models import ScalewayQaasV1Alpha1Job as QaaSJob
from quantum_as_a_service_api_client.models import (
    ScalewayQaasV1Alpha1JobResult as QaaSJobResut,
)
from quantum_as_a_service_api_client.models import (
    ScalewayQaasV1Alpha1JobStatus as QaaSJobStatus,
)
from quantum_as_a_service_api_client.models import (
    ScalewayQaasV1Alpha1Session as QaaSSession,
)
from quantum_as_a_service_api_client.models import (
    ScalewayQaasV1Alpha1SessionStatus as QaaSSessionStatus,
)
from quantum_as_a_service_api_client.models import (
    ScalewayQaasV1Alpha1Application as QaaSApplication,
)
from quantum_as_a_service_api_client.models import (
    ScalewayQaasV1Alpha1Process as QaaSProcess,
)
from quantum_as_a_service_api_client.models import (
    ScalewayQaasV1Alpha1ProcessResult as QaaSProcessResult,
)
from quantum_as_a_service_api_client.models import (
    ScalewayQaasV1Alpha1ProcessStatus as QaaSProcessStatus,
)
from job_payload.models import (
    QaaSCircuitSerializationFormat,
    QaaSCircuitData,
    QaaSJobBackendData,
    QaaSJobClientData,
    QaaSJobData,
    QaaSJobRunData,
)
from .client import QaaSClient

==> scaleway_qaas_client-0.1.10.tar.gz: scaleway_qaas_client-0.1.10/scaleway_qaas_client/__init__.py <==
# Copyright 2025 Scaleway
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
from .client import QaaSClient
from .job_payload.models import (
    QaaSCircuitData,
    QaaSCircuitSerializationFormat,
    QaaSJobBackendData,
    QaaSJobClientData,
    QaaSJobData,
    QaaSJobRunData,
)
from .quantum_as_a_service_api_client.models import (
    ScalewayQaasV1Alpha1Application as QaaSApplication,
)
from .quantum_as_a_service_api_client.models import ScalewayQaasV1Alpha1Job as QaaSJob
from .quantum_as_a_service_api_client.models import (
    ScalewayQaasV1Alpha1JobResult as QaaSJobResult,
)
from .quantum_as_a_service_api_client.models import (
    ScalewayQaasV1Alpha1JobResult as QaaSJobResut,
)
from .quantum_as_a_service_api_client.models import (
    ScalewayQaasV1Alpha1JobStatus as QaaSJobStatus,
)
from .quantum_as_a_service_api_client.models import (
    ScalewayQaasV1Alpha1Platform as QaaSPlatform,
)
from .quantum_as_a_service_api_client.models import (
    ScalewayQaasV1Alpha1PlatformAvailability as QaaSPlatformAvailability,
)
from .quantum_as_a_service_api_client.models import (
    ScalewayQaasV1Alpha1PlatformTechnology as QaaSPlatformTechnology,
)
from .quantum_as_a_service_api_client.models import (
    ScalewayQaasV1Alpha1Process as QaaSProcess,
)
from .quantum_as_a_service_api_client.models import (
    ScalewayQaasV1Alpha1ProcessResult as QaaSProcessResult,
)
from .quantum_as_a_service_api_client.models import (
    ScalewayQaasV1Alpha1ProcessStatus as QaaSProcessStatus,
)
from .quantum_as_a_service_api_client.models import (
    ScalewayQaasV1Alpha1Session as QaaSSession,
)
from .quantum_as_a_service_api_client.models import (
    ScalewayQaasV1Alpha1SessionStatus as QaaSSessionStatus,
)
